@@ -23,7 +23,7 @@ try:
 except:
     print("Unable to import Ipyvolume")
 
-__VERSION__ = "0.0.16"
+__VERSION__ = "0.0.19"
 
 """
     A module to analyze cytosim simulations
@@ -136,8 +136,6 @@ class Simulation(list):
         self.id = 0
         self.n_frames=0
         self.shown = False
-        self.figure = None
-
         # Actual initialization
         self.initialize(*args,**kwargs)
 
@@ -232,9 +230,6 @@ class Simulation(list):
         if not __IPV__:
             raise ValueError("Could not import module iPyVolume")
         else:
-            #fig = ipv.figure()
-            #if self.figure is None:
-            #    self.figure = ipv.figure()
 
             if len(args) == 0:
                 ipv.show()
@@ -283,3 +278,8 @@ class Simulation(list):
             self.show()
             #widgets.HBox([play, slider])
 
+    def figure(self):
+        if not __IPV__:
+            raise ValueError("Could not import module iPyVolume")
+        else:
+            ipv.figure()
\ No newline at end of file
